@@ -20,14 +20,14 @@ class BaseTV(object):
 
     .. code-block:: python
 
-       state_detection_rules = {'com.amazon.tv.launcher': ['standby'],
+       state_detection_rules = {'com.amazon.tv.launcher': ['idle'],
                                 'com.netflix.ninja': ['media_session_state'],
                                 'com.ellation.vrv': ['audio_state'],
                                 'com.hulu.plus': [{'playing': {'wake_lock_size' : 4}},
                                                   {'paused': {'wake_lock_size': 2}}],
                                 'com.plexapp.android': [{'paused': {'media_session_state': 3, 'wake_lock_size': 1}},
                                                         {'playing': {'media_session_state': 3}},
-                                                        'standby']}
+                                                        'idle']}
 
     The keys are app IDs, and the values are lists of rules that are evaluated in order.
 
@@ -40,7 +40,7 @@ class BaseTV(object):
 
     **Valid rules:**
 
-    * ``'standby'``, ``'playing'``, ``'paused'``, ``'idle'``, or ``'off'`` = always report the specified state when this app is open
+    * ``'idle'``, ``'playing'``, ``'paused'``, ``'standby'``, or ``'off'`` = always report the specified state when this app is open
     * ``'media_session_state'`` = try to use the :meth:`media_session_state` property to determine the state
     * ``'audio_state'`` = try to use the :meth:`audio_state` property to determine the state
     * ``{'<VALID_STATE>': {'<PROPERTY1>': VALUE1, '<PROPERTY2>': VALUE2, ...}}`` = check if each of the properties is equal to the specified value, and if so return the state
@@ -283,7 +283,7 @@ class BaseTV(object):
                 if media_session_state == 3:
                     return constants.STATE_PLAYING
                 if media_session_state is not None:
-                    return constants.STATE_STANDBY
+                    return constants.STATE_IDLE
 
             # Use the `audio_state` property
             if rule == 'audio_state' and audio_state in constants.VALID_STATES:
@@ -1155,6 +1155,53 @@ class BaseTV(object):
         # return the new volume level
         return max(current_volume - 1, 0.) / self.max_volume
 
+    # ======================================================================= #
+    #                                                                         #
+    #                          Miscellaneous methods                          #
+    #                                                                         #
+    # ======================================================================= #
+    async def learn_sendevent(self, timeout_s=8):
+        """Capture an event (e.g., a button press) via ``getevent`` and convert it into ``sendevent`` commands.
+
+        For more info, see:
+
+        * http://ktnr74.blogspot.com/2013/06/emulating-touchscreen-interaction-with.html?m=1
+        * https://qatesttech.wordpress.com/2012/06/21/turning-the-output-from-getevent-into-something-something-that-can-be-used/
+
+        Parameters
+        ----------
+        timeout_s : int
+            The timeout in seconds to wait for events
+
+        Returns
+        -------
+        str
+            The events converted to ``sendevent`` commands
+
+        """
+        getevent = await self.adb_shell("( getevent ) & pid=$!; ( sleep {} && kill -HUP $pid ) 2>/dev/null & watcher=$!; if wait $pid 2>/dev/null; then echo 'your command finished'; kill -HUP -P $watcher; wait $watcher; else echo 'your command was interrupted'; fi".format(timeout_s))
+
+        return " && ".join([self._parse_getevent_line(line) for line in getevent.splitlines() if line.startswith("/") and ":" in line])
+
+    @staticmethod
+    def _parse_getevent_line(line):
+        """Parse a line of the output received in ``learn_sendevent``.
+
+        Parameters
+        ----------
+        line : str
+            A line of output from ``learn_sendevent``
+
+        Returns
+        -------
+        str
+            The properly formatted ``sendevent`` command
+
+        """
+        device_name, event_info = line.split(":", 1)
+        integers = [int(x, 16) for x in event_info.strip().split()[:3]]
+        return "sendevent {} {} {} {}".format(device_name, *integers)
+
 
 # ======================================================================= #
 #                                                                         #
